@@ -47,8 +47,8 @@ class AlbHttpsTest(unittest.TestCase):
             'Listener resource with fix response "401 Access Denied" exists'
         )
         self.assertIn(
-            '"Port": 443, "Protocol": "HTTPS", "Certificates": [{"CertificateArn": '
-            '"arn:aws:acm:us-east-1:023475735288:certificate/ff6967d7-0fdf-4967-bd68-4caffc983447"}]',
+            '"Certificates": [{"CertificateArn": "arn:aws:acm:us-east-1:023475735288:certificate/ff6967d7-0fdf-4967'
+            '-bd68-4caffc983447"}], "Port": 443, "Protocol": "HTTPS"}}',
             template,
             'Listener is on HTTPS and has the provided certificate'
         )
